@@ -1,6 +1,6 @@
 """
 ********************************************************************************
-compas.viewers
+viewers
 ********************************************************************************
 
 .. currentmodule:: compas.viewers
@@ -18,6 +18,8 @@ Classes
 
 """
 from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
 
 from .core import *
 from .viewer import *
@@ -28,19 +30,4 @@ try:
 except:
     pass
 
-from . import viewer
-from . import meshviewer
-
-try:
-    from . import vtkviewer
-except:
-    pass
-
-__all__ = []
-__all__ += viewer.__all__
-__all__ += meshviewer.__all__
-
-try:
-    __all__ += vtkviewer.__all__
-except:
-    pass
+__all__ = [name for name in dir() if not name.startswith('_')]
